==> green-core-1.80.0.tgz: package/components/input/input.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _shouldShowFooter, shouldShowFooter_fn, _handleOnInput, _handleOnChange, _handleFieldClick, _handleClearBtnClick, _renderFieldContents, renderFieldContents_fn, _renderSlotLead, renderSlotLead_fn, _renderSlotTrail, renderSlotTrail_fn, _renderNativeInput, renderNativeInput_fn, _renderClearButton, renderClearButton_fn, _shouldShowRemainingChars, shouldShowRemainingChars_get;
import { localized, msg } from "@lit/localize";
import { property, query, queryAsync } from "lit/decorators.js";
import { ifDefined } from "lit/directives/if-defined.js";
import { when } from "lit/directives/when.js";
import { nothing } from "lit/html.js";
import { GdsFieldBase } from "../../primitives/field-base/field-base.component.js";
import { GdsFormControlFooter } from "../../primitives/form-control-footer/form-control-footer.component.js";
import { GdsFormControlHeader } from "../../primitives/form-control-header/form-control-header.component.js";
import { gdsCustomElement, html } from "../../scoping.js";
import formControlHostStyles from "../../shared-styles/form-control-host.style.js";
import { tokens } from "../../tokens.style.js";
import {
  withLayoutChildProps,
  withMarginProps,
  withSizeXProps
} from "../../utils/mixins/declarative-layout-mixins.js";
import { GdsButton } from "../button/button.component.js";
import { GdsFlex } from "../flex/flex.component.js";
import { GdsFormControlElement } from "../form/form-control.js";
import { IconCrossLarge } from "../icon/icons/cross-large.component.js";
import { styles } from "./input.styles.js";
let Input = class extends GdsFormControlElement {
  constructor() {
    super();
    __privateAdd(this, _shouldShowFooter);
    __privateAdd(this, _renderFieldContents);
    __privateAdd(this, _renderSlotLead);
    __privateAdd(this, _renderSlotTrail);
    __privateAdd(this, _renderNativeInput);
    __privateAdd(this, _renderClearButton);
    __privateAdd(this, _shouldShowRemainingChars);
    this.supportingText = "";
    this.showExtendedSupportingText = false;
    this.clearable = false;
    this.maxlength = Number.MAX_SAFE_INTEGER;
    this.size = "large";
    this.plain = false;
    this.type = "text";
    this.autocapitalize = "off";
    this.autofocus = false;
    this.spellcheck = true;
    __privateAdd(this, _handleOnInput, (e) => {
      const element = e.target;
      this.value = element.value;
    });
    __privateAdd(this, _handleOnChange, (e) => {
      const element = e.target;
      this.value = element.value;
      this.dispatchEvent(
        new Event("change", {
          bubbles: true,
          composed: true
        })
      );
    });
    __privateAdd(this, _handleFieldClick, () => {
      this.elInputAsync.then((el) => el.focus());
    });
    __privateAdd(this, _handleClearBtnClick, () => {
      this.value = "";
      this.dispatchEvent(
        new Event("gds-input-cleared", {
          bubbles: true,
          composed: true
        })
      );
      this.dispatchEvent(
        new Event("input", {
          bubbles: true,
          composed: true
        })
      );
    });
    this.value = "";
  }
  /**
   * A reference to the clear button element. Returns null if there is no clear button.
   * Intended for use in integration tests.
   */
  test_getClearButton() {
    return this.shadowRoot?.querySelector("#clear-button");
  }
  /**
   * A reference to the field element. This does not refer to the input element itself,
   * but the wrapper that makes up the visual field.
   * Intended for use in integration tests.
   */
  test_getFieldElement() {
    return this.shadowRoot?.querySelector("#field");
  }
  render() {
    return html`
      ${when(
      !this.plain,
      () => html`<gds-form-control-header class="size-${this.size}">
            <label for="input" slot="label">${this.label}</label>
            <span slot="supporting-text" id="supporting-text">
              ${this.supportingText}
            </span>
            <slot
              name="extended-supporting-text"
              slot="extended-supporting-text"
            ></slot>
          </gds-form-control-header>`
    )}
      <gds-field-base
        .size=${this.size}
        .disabled=${this.disabled}
        .invalid=${this.invalid}
        @click=${__privateGet(this, _handleFieldClick)}
        id="field"
      >
        ${__privateMethod(this, _renderFieldContents, renderFieldContents_fn).call(this)}
      </gds-field-base>
      ${when(
      __privateMethod(this, _shouldShowFooter, shouldShowFooter_fn).call(this),
      () => html`<gds-form-control-footer
            class="size-${this.size}"
            .charCounter=${__privateGet(this, _shouldShowRemainingChars, shouldShowRemainingChars_get) && this.maxlength - (this.value?.length || 0)}
            .validationMessage=${this.invalid && (this.errorMessage || this.validationMessage)}
          ></gds-form-control-footer>`
    )}
    `;
  }
  _getValidityAnchor() {
    return this.elInput;
  }
};
_shouldShowFooter = new WeakSet();
shouldShowFooter_fn = function() {
  return !this.plain && (this.invalid || __privateGet(this, _shouldShowRemainingChars, shouldShowRemainingChars_get));
};
_handleOnInput = new WeakMap();
_handleOnChange = new WeakMap();
_handleFieldClick = new WeakMap();
_handleClearBtnClick = new WeakMap();
_renderFieldContents = new WeakSet();
renderFieldContents_fn = function() {
  const elements = [
    __privateMethod(this, _renderSlotLead, renderSlotLead_fn).call(this),
    __privateMethod(this, _renderNativeInput, renderNativeInput_fn).call(this),
    __privateMethod(this, _renderClearButton, renderClearButton_fn).call(this),
    __privateMethod(this, _renderSlotTrail, renderSlotTrail_fn).call(this)
  ];
  return elements.map((element) => html`${element}`);
};
_renderSlotLead = new WeakSet();
renderSlotLead_fn = function() {
  return html` <slot slot="lead" name="lead"></slot> `;
};
_renderSlotTrail = new WeakSet();
renderSlotTrail_fn = function() {
  return html`<slot slot="trail" name="trail"></slot>`;
};
_renderNativeInput = new WeakSet();
renderNativeInput_fn = function() {
  return html`
      <input
        class="native-control"
        @input=${__privateGet(this, _handleOnInput)}
        @change=${__privateGet(this, _handleOnChange)}
        .value=${this.value}
        id="input"
        ?disabled=${this.disabled}
        aria-describedby="supporting-text extended-supporting-text sub-label message"
        aria-invalid=${this.invalid}
        aria-label=${this.plain && this.label || nothing}
        placeholder=" "
        type=${this.type}
        min=${ifDefined(this.min)}
        max=${ifDefined(this.max)}
        step=${ifDefined(this.step)}
        autocapitalize=${ifDefined(this.autocapitalize)}
        autocomplete=${ifDefined(this.autocomplete)}
        autocorrect=${ifDefined(this.autocorrect)}
        ?autofocus=${this.autofocus}
        spellcheck=${this.spellcheck}
        enterkeyhint=${ifDefined(this.enterkeyhint)}
        inputmode=${ifDefined(this.inputmode)}
        ?required=${this.required}
      />
    `;
};
_renderClearButton = new WeakSet();
renderClearButton_fn = function() {
  if (this.clearable && (this.value?.length || 0) > 0)
    return html`<gds-button
        size="${this.size === "small" ? "xs" : "small"}"
        rank="tertiary"
        variant="${this.invalid ? "negative" : ""}"
        ?disabled="${this.disabled}"
        label="${msg("Clear input")}"
        @click=${__privateGet(this, _handleClearBtnClick)}
        id="clear-button"
        slot="action"
      >
        <gds-icon-cross-large />
      </gds-button>`;
  else
    return nothing;
};
_shouldShowRemainingChars = new WeakSet();
shouldShowRemainingChars_get = function() {
  return this.maxlength < Number.MAX_SAFE_INTEGER;
};
Input.styles = [tokens, formControlHostStyles, styles];
__decorateClass([
  property({ attribute: "supporting-text" })
], Input.prototype, "supportingText", 2);
__decorateClass([
  property({
    attribute: "show-extended-supporting-text",
    type: Boolean,
    reflect: true
  })
], Input.prototype, "showExtendedSupportingText", 2);
__decorateClass([
  property({ type: Boolean })
], Input.prototype, "clearable", 2);
__decorateClass([
  property({ type: Number })
], Input.prototype, "maxlength", 2);
__decorateClass([
  property({ type: String })
], Input.prototype, "size", 2);
__decorateClass([
  property({ type: Boolean })
], Input.prototype, "plain", 2);
__decorateClass([
  property({ reflect: true })
], Input.prototype, "type", 2);
__decorateClass([
  property()
], Input.prototype, "min", 2);
__decorateClass([
  property()
], Input.prototype, "max", 2);
__decorateClass([
  property()
], Input.prototype, "step", 2);
__decorateClass([
  property()
], Input.prototype, "autocapitalize", 2);
__decorateClass([
  property()
], Input.prototype, "autocorrect", 2);
__decorateClass([
  property()
], Input.prototype, "autocomplete", 2);
__decorateClass([
  property({ type: Boolean })
], Input.prototype, "autofocus", 2);
__decorateClass([
  property()
], Input.prototype, "enterkeyhint", 2);
__decorateClass([
  property({
    type: Boolean,
    converter: {
      // Allow "true|false" attribute values but keep the property boolean
      fromAttribute: (value) => !value || value === "false" ? false : true,
      toAttribute: (value) => value ? "true" : "false"
    }
  })
], Input.prototype, "spellcheck", 2);
__decorateClass([
  property()
], Input.prototype, "inputmode", 2);
__decorateClass([
  queryAsync("input")
], Input.prototype, "elInputAsync", 2);
__decorateClass([
  query("input")
], Input.prototype, "elInput", 2);
Input = __decorateClass([
  localized()
], Input);
let GdsInput = class extends withSizeXProps(
  withMarginProps(withLayoutChildProps(Input))
) {
};
GdsInput = __decorateClass([
  gdsCustomElement("gds-input", {
    dependsOn: [
      GdsFormControlHeader,
      GdsFormControlFooter,
      GdsFieldBase,
      GdsFlex,
      GdsButton,
      IconCrossLarge
    ]
  })
], GdsInput);
export {
  GdsInput
};

==> green-core-1.82.0.tgz: package/components/input/input.component.js <==
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _shouldShowFooter, shouldShowFooter_fn, _handleOnInput, _handleOnChange, _handleFieldClick, _handleClearBtnClick, _renderFieldContents, renderFieldContents_fn, _renderSlotLead, renderSlotLead_fn, _renderSlotTrail, renderSlotTrail_fn, _renderNativeInput, renderNativeInput_fn, _renderClearButton, renderClearButton_fn, _shouldShowRemainingChars, shouldShowRemainingChars_get;
import { localized, msg } from "@lit/localize";
import { property, query, queryAsync } from "lit/decorators.js";
import { ifDefined } from "lit/directives/if-defined.js";
import { when } from "lit/directives/when.js";
import { nothing } from "lit/html.js";
import { GdsFieldBase } from "../../primitives/field-base/field-base.component.js";
import { GdsFormControlFooter } from "../../primitives/form-control-footer/form-control-footer.component.js";
import { GdsFormControlHeader } from "../../primitives/form-control-header/form-control-header.component.js";
import { gdsCustomElement, html } from "../../scoping.js";
import formControlHostStyles from "../../shared-styles/form-control-host.style.js";
import { tokens } from "../../tokens.style.js";
import {
  withLayoutChildProps,
  withMarginProps,
  withSizeXProps
} from "../../utils/mixins/declarative-layout-mixins.js";
import { GdsButton } from "../button/button.component.js";
import { GdsFlex } from "../flex/flex.component.js";
import { GdsFormControlElement } from "../form/form-control.js";
import { IconCrossLarge } from "../icon/icons/cross-large.component.js";
import { styles } from "./input.styles.js";
let Input = class extends GdsFormControlElement {
  constructor() {
    super();
    __privateAdd(this, _shouldShowFooter);
    __privateAdd(this, _renderFieldContents);
    __privateAdd(this, _renderSlotLead);
    __privateAdd(this, _renderSlotTrail);
    __privateAdd(this, _renderNativeInput);
    __privateAdd(this, _renderClearButton);
    __privateAdd(this, _shouldShowRemainingChars);
    this.supportingText = "";
    this.showExtendedSupportingText = false;
    this.clearable = false;
    this.maxlength = Number.MAX_SAFE_INTEGER;
    this.size = "large";
    this.plain = false;
    this.type = "text";
    this.autocapitalize = "off";
    this.autofocus = false;
    this.spellcheck = true;
    __privateAdd(this, _handleOnInput, (e) => {
      const element = e.target;
      this.value = element.value;
    });
    __privateAdd(this, _handleOnChange, (e) => {
      const element = e.target;
      this.value = element.value;
      this.dispatchEvent(
        new Event("change", {
          bubbles: true,
          composed: true
        })
      );
    });
    __privateAdd(this, _handleFieldClick, () => {
      this.elInputAsync.then((el) => el.focus());
    });
    __privateAdd(this, _handleClearBtnClick, () => {
      this.value = "";
      this.dispatchEvent(
        new Event("gds-input-cleared", {
          bubbles: true,
          composed: true
        })
      );
      this.dispatchEvent(
        new Event("input", {
          bubbles: true,
          composed: true
        })
      );
    });
    this.value = "";
  }
  /**
   * A reference to the clear button element. Returns null if there is no clear button.
   * Intended for use in integration tests.
   */
  test_getClearButton() {
    return this.shadowRoot?.querySelector("#clear-button");
  }
  /**
   * A reference to the field element. This does not refer to the input element itself,
   * but the wrapper that makes up the visual field.
   * Intended for use in integration tests.
   */
  test_getFieldElement() {
    return this.shadowRoot?.querySelector("#field");
  }
  render() {
    return html`
      ${when(
      !this.plain,
      () => html`<gds-form-control-header class="size-${this.size}">
            <label for="input" slot="label">${this.label}</label>
            <span slot="supporting-text" id="supporting-text">
              ${this.supportingText}
            </span>
            <slot
              name="extended-supporting-text"
              slot="extended-supporting-text"
            ></slot>
          </gds-form-control-header>`
    )}
      <gds-field-base
        .size=${this.size}
        .disabled=${this.disabled}
        .invalid=${this.invalid}
        @click=${__privateGet(this, _handleFieldClick)}
        id="field"
      >
        ${__privateMethod(this, _renderFieldContents, renderFieldContents_fn).call(this)}
      </gds-field-base>
      ${when(
      __privateMethod(this, _shouldShowFooter, shouldShowFooter_fn).call(this),
      () => html` <gds-form-control-footer
            class="size-${this.size}"
            .charCounter=${__privateGet(this, _shouldShowRemainingChars, shouldShowRemainingChars_get) ? this.maxlength - (this.value?.length || 0) : void 0}
            .errorMessage=${this.invalid ? this.errorMessage : void 0}
          ></gds-form-control-footer>`
    )}
    `;
  }
  _getValidityAnchor() {
    return this.elInput;
  }
};
_shouldShowFooter = new WeakSet();
shouldShowFooter_fn = function() {
  return !this.plain;
};
_handleOnInput = new WeakMap();
_handleOnChange = new WeakMap();
_handleFieldClick = new WeakMap();
_handleClearBtnClick = new WeakMap();
_renderFieldContents = new WeakSet();
renderFieldContents_fn = function() {
  const elements = [
    __privateMethod(this, _renderSlotLead, renderSlotLead_fn).call(this),
    __privateMethod(this, _renderNativeInput, renderNativeInput_fn).call(this),
    __privateMethod(this, _renderClearButton, renderClearButton_fn).call(this),
    __privateMethod(this, _renderSlotTrail, renderSlotTrail_fn).call(this)
  ];
  return elements.map((element) => html`${element}`);
};
_renderSlotLead = new WeakSet();
renderSlotLead_fn = function() {
  return html` <slot slot="lead" name="lead"></slot> `;
};
_renderSlotTrail = new WeakSet();
renderSlotTrail_fn = function() {
  return html`<slot slot="trail" name="trail"></slot>`;
};
_renderNativeInput = new WeakSet();
renderNativeInput_fn = function() {
  return html`
      <input
        class="native-control"
        @input=${__privateGet(this, _handleOnInput)}
        @change=${__privateGet(this, _handleOnChange)}
        .value=${this.value}
        id="input"
        ?disabled=${this.disabled}
        aria-describedby="supporting-text extended-supporting-text sub-label message"
        aria-invalid=${this.invalid}
        aria-label=${this.plain && this.label || nothing}
        placeholder=" "
        type=${this.type}
        min=${ifDefined(this.min)}
        max=${ifDefined(this.max)}
        step=${ifDefined(this.step)}
        autocapitalize=${ifDefined(this.autocapitalize)}
        autocomplete=${ifDefined(this.autocomplete)}
        autocorrect=${ifDefined(this.autocorrect)}
        ?autofocus=${this.autofocus}
        spellcheck=${this.spellcheck}
        enterkeyhint=${ifDefined(this.enterkeyhint)}
        inputmode=${ifDefined(this.inputmode)}
        ?required=${this.required}
      />
    `;
};
_renderClearButton = new WeakSet();
renderClearButton_fn = function() {
  if (this.clearable && (this.value?.length || 0) > 0)
    return html`<gds-button
        size="${this.size === "small" ? "xs" : "small"}"
        rank="tertiary"
        variant="${this.invalid ? "negative" : ""}"
        ?disabled="${this.disabled}"
        label="${msg("Clear input")}"
        @click=${__privateGet(this, _handleClearBtnClick)}
        id="clear-button"
        slot="action"
      >
        <gds-icon-cross-large />
      </gds-button>`;
  else
    return nothing;
};
_shouldShowRemainingChars = new WeakSet();
shouldShowRemainingChars_get = function() {
  return this.maxlength < Number.MAX_SAFE_INTEGER;
};
Input.styles = [tokens, formControlHostStyles, styles];
__decorateClass([
  property({ attribute: "supporting-text" })
], Input.prototype, "supportingText", 2);
__decorateClass([
  property({
    attribute: "show-extended-supporting-text",
    type: Boolean,
    reflect: true
  })
], Input.prototype, "showExtendedSupportingText", 2);
__decorateClass([
  property({ type: Boolean })
], Input.prototype, "clearable", 2);
__decorateClass([
  property({ type: Number })
], Input.prototype, "maxlength", 2);
__decorateClass([
  property({ type: String })
], Input.prototype, "size", 2);
__decorateClass([
  property({ type: Boolean })
], Input.prototype, "plain", 2);
__decorateClass([
  property({ reflect: true })
], Input.prototype, "type", 2);
__decorateClass([
  property()
], Input.prototype, "min", 2);
__decorateClass([
  property()
], Input.prototype, "max", 2);
__decorateClass([
  property()
], Input.prototype, "step", 2);
__decorateClass([
  property()
], Input.prototype, "autocapitalize", 2);
__decorateClass([
  property()
], Input.prototype, "autocorrect", 2);
__decorateClass([
  property()
], Input.prototype, "autocomplete", 2);
__decorateClass([
  property({ type: Boolean })
], Input.prototype, "autofocus", 2);
__decorateClass([
  property()
], Input.prototype, "enterkeyhint", 2);
__decorateClass([
  property({
    type: Boolean,
    converter: {
      // Allow "true|false" attribute values but keep the property boolean
      fromAttribute: (value) => !value || value === "false" ? false : true,
      toAttribute: (value) => value ? "true" : "false"
    }
  })
], Input.prototype, "spellcheck", 2);
__decorateClass([
  property()
], Input.prototype, "inputmode", 2);
__decorateClass([
  queryAsync("input")
], Input.prototype, "elInputAsync", 2);
__decorateClass([
  query("input")
], Input.prototype, "elInput", 2);
Input = __decorateClass([
  localized()
], Input);
let GdsInput = class extends withSizeXProps(
  withMarginProps(withLayoutChildProps(Input))
) {
};
GdsInput = __decorateClass([
  gdsCustomElement("gds-input", {
    dependsOn: [
      GdsFormControlHeader,
      GdsFormControlFooter,
      GdsFieldBase,
      GdsFlex,
      GdsButton,
      IconCrossLarge
    ]
  })
], GdsInput);
export {
  GdsInput
};
